//! bare2.rs
//! Simple bare metal application
#![feature(used)]
#![no_std]

extern crate cortex_m;
extern crate cortex_m_rt;

#[macro_use]
extern crate cortex_m_debug;

// burns CPU cycles by just looping `i` times
fn wait(i: u32) {
    for _ in 0..i {
        // no operation (ensured not optimized out)
        cortex_m::asm::nop();
    }
}

fn main() {
    ipln!("Start");

    // a "mutable" (changeable) variable
    let mut s = 0;

    loop {
        ipln!("s = {}", s);
        s += 1;
        wait(100_000);
    }
}

// As we are not using interrupts, we just register a dummy catch all handler
#[link_section = ".vector_table.interrupts"]
#[used]
static INTERRUPTS: [extern "C" fn(); 240] = [default_handler; 240];

extern "C" fn default_handler() {
    cortex_m::asm::bkpt();
}
